#!/bin/bash

function error_with_msg {
    if [[ "$count" -eq 0 ]]
    then
        echo
        echo >&2 "$1"
        exit 1
    fi
}

function check_running_status {
    for count in {10..0}; do
        STATUS=$(/usr/bin/supervisorctl status $1 | awk '{print $2}')
        echo "- $1 is in the $STATUS state."
        if [[ "$STATUS" = "RUNNING" ]]
        then
            break
        else
            sleep 1
        fi
    done
}

function check_port_status {
    for count in {10..0}; do
        echo 2>/dev/null >/dev/tcp/localhost/$1
        if [[ "$?" -eq 0 ]]
        then
            echo "- Port $1 is listening"
            break
        else
            echo "- Port $1 is not listening"
            sleep 1
        fi
    done
}

function start_service {
    echo "- Starting $1"
    /usr/bin/supervisorctl start $1
    check_running_status $1
}

function check_stopped {
    for count in {30..0}; do
        if echo "SELECT 1" | $1 &> /dev/null; then
            sleep 1
        else
            break
        fi
    done
    if [[ "$count" -eq 0 ]]; then
        echo >&2 $1" did not stop"
        exit 1
    fi
}

if [ ! -d "/var/lib/mysql/slurm_acct_db" ]; then
    /usr/bin/mysqld_safe --datadir='/var/lib/mysql' &

    for count in {30..0}; do
        if echo "SELECT 1" | mysql &> /dev/null; then
            break
        fi
        echo "- Starting MariaDB to create Slurm account database"
        sleep 1
    done

    if [[ "$count" -eq 0 ]]; then
        echo >&2 "MariaDB did not start"
        exit 1
    fi

    echo "- Creating Slurm acct database"
    mysql -NBe "CREATE DATABASE slurm_acct_db"
    mysql -NBe "GRANT USAGE ON *.* to 'root'@'localhost'"
    mysql -NBe "GRANT ALL PRIVILEGES on slurm_acct_db.* to 'root'@'localhost'"
    mysql -NBe "FLUSH PRIVILEGES"
    echo "- Slurm acct database created."
    killall mysqld
    #check_stopped mysqld
fi

echo "- Starting supervisord process manager"
/usr/bin/supervisord --configuration /etc/supervisord.conf

# check if supervisord has launched mysqld
check_running_status mysqld

# wait for slurmdbd to spool up
sleep 10

echo "- Launching slurmdbd"
start_service slurmdbd
check_running_status slurmdbd

# configure database 
pushd /opt/ces_slurm_simulator_tools/install/slurm_programs/bin
./sacctmgr -i modify QOS set normal priority=0
sleep 2
./sacctmgr -i add cluster name=slurm_sim fairshare=1 qos=normal
echo "- Configured cluster"
killall slurmdbd
echo "- Stopped slurmdbd"
popd 

# finally set environmental flag to use the 
export USERNAME=root

exec "$@"

